==> netxms-2.0.tar.gz: netxms-2.0/src/agent/subagents/java/java/src/main/java/org/netxms/agent/adapters/ActionAdapter.java <==
/**
 * Java-Bridge NetXMS subagent
 * Copyright (c) 2013 TEMPEST a.s.
 * Copyright (c) 2015 Raden Solutions SIA
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.agent.adapters;

import org.netxms.agent.Action;

/**
 * Adapter for Action interface
 */
public abstract class ActionAdapter implements Action
{
   private String name;
   private String description;

   /**
    * @param name
    * @param description
    */
   public ActionAdapter(String name, String description)
   {
      this.name = name;
      this.description = description;
   }

   /* (non-Javadoc)
    * @see org.netxms.agent.AgentContributionItem#getName()
    */
   @Override
   public String getName()
   {
      return name;
   }

   /* (non-Javadoc)
    * @see org.netxms.agent.AgentContributionItem#getDescription()
    */
   @Override
   public String getDescription()
   {
      return description;
   }
}

==> netxms-3.9.280.tar.gz: netxms-3.9.280/src/agent/subagents/java/java/src/main/java/org/netxms/agent/adapters/ActionAdapter.java <==
/**
 * Java-Bridge NetXMS subagent
 * Copyright (c) 2013 TEMPEST a.s.
 * Copyright (c) 2015 Raden Solutions SIA
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.agent.adapters;

import org.netxms.agent.Action;

/**
 * Adapter for Action interface
 */
public abstract class ActionAdapter extends AbstractAdapter implements Action
{
   private String name;
   private String description;

   /**
    * @param name action name
    * @param description action description
    */
   public ActionAdapter(String name, String description)
   {
      this.name = name;
      this.description = description;
   }

   /* (non-Javadoc)
    * @see org.netxms.agent.AgentContributionItem#getName()
    */
   @Override
   public String getName()
   {
      return name;
   }

   /* (non-Javadoc)
    * @see org.netxms.agent.AgentContributionItem#getDescription()
    */
   @Override
   public String getDescription()
   {
      return description;
   }
}
